@@ -8,8 +8,8 @@ for which a new license (GPL+exception) is in place.
 #include "sclcmscolortransformimpl.h"
 #include "sclcmscolormgmtengineimpl.h"
 
-ScLcmsColorTransformImpl::ScLcmsColorTransformImpl(cmsHTRANSFORM lcmsTransform)
-                        : ScColorTransformData(), m_transformHandle(lcmsTransform)
+ScLcmsColorTransformImpl::ScLcmsColorTransformImpl(ScColorMgmtEngine& engine, cmsHTRANSFORM lcmsTransform)
+                        : ScColorTransformImplBase(engine), m_transformHandle(lcmsTransform)
 {
 
 }
@@ -21,7 +21,7 @@ ScLcmsColorTransformImpl::~ScLcmsColorTransformImpl()
 
 bool ScLcmsColorTransformImpl::isNull() const
 {
-	return (m_transformHandle == NULL);
+	return (m_transformHandle == nullptr);
 }
 
 bool ScLcmsColorTransformImpl::apply(void* input, void* output, uint numElem)
@@ -44,22 +44,12 @@ bool ScLcmsColorTransformImpl::apply(QByteArray& input, QByteArray& output, uint
 	return false;
 }
 
-void ScLcmsColorTransformImpl::changeBufferFormat(eColorFormat inputFormat, eColorFormat outputFormat)
-{
-	if (m_transformHandle)
-	{
-		DWORD lcmsInputF  = ScLcmsColorMgmtEngineImpl::translateFormatToLcmsFormat(inputFormat);
-		DWORD lcmsOutputF = ScLcmsColorMgmtEngineImpl::translateFormatToLcmsFormat(outputFormat);
-		cmsChangeBuffersFormat(m_transformHandle, lcmsInputF, lcmsOutputF);
-	}
-}
-
 void ScLcmsColorTransformImpl::deleteTransform(void)
 {
 	if (m_transformHandle)
 	{
 		cmsDeleteTransform(m_transformHandle);
-		m_transformHandle = NULL;
+		m_transformHandle = nullptr;
 	}
 }
 
