@@ -323,7 +323,7 @@ bool FileLoader::readPageCount(int *num1, int *num2, QStringList & masterPageNam
 	return false;
 }
 
-bool FileLoader::readLineStyles(QHash<QString,multiLine> *Sty)
+bool FileLoader::readLineStyles(QHash<QString, MultiLine> *Sty)
 {
 	QList<FileFormat>::const_iterator it;
 	if (findFormat(m_fileType, it))
