@@ -7,6 +7,7 @@ for which a new license (GPL+exception) is in place.
 #ifndef _PLUGIN_MANAGER_
 #define _PLUGIN_MANAGER_
 
+#include <QFunctionPointer>
 #include <QObject>
 #include <QString>
 #include <QMap>
@@ -38,13 +39,12 @@ class SCRIBUS_API PluginManager : public QObject
 
 public:
 	PluginManager();
-	~PluginManager();
 
 	/*! \brief Static methods for loading, unloading plugins and resolving symbols
 	 These methods are platform independent, but each platform uses a different
 	 implementation. */
 	static void* loadDLL(const QString& plugin);
-	static void* resolveSym( void* plugin, const char* sym );
+	static QFunctionPointer resolveSym(void* plugin, const char* sym);
 	static void  unloadDLL( void* plugin );
 
 	/*! \brief Initialization of all plugins. It's called at scribus start.
@@ -161,10 +161,10 @@ protected:
 	{
 		QString pluginFile; // Datei;
 		QString pluginName;
-		void* pluginDLL;
-		ScPlugin* plugin;
-		bool enableOnStartup;
-		bool enabled;
+		void* pluginDLL { nullptr };
+		ScPlugin* plugin { nullptr };
+		bool enableOnStartup { false };
+		bool enabled { false };
 		QString version;
 	};
 
@@ -203,7 +203,7 @@ protected:
 	void finalizePlug(PluginData & pluginData);
 
 	/** \brief Configuration structure */
-	PrefsContext* prefs;
+	PrefsContext* prefs { nullptr };
 
 	/*! \brief Mapping of plugin names to plugin info structures. */
 	typedef QMap<QString,PluginData> PluginMap;
