@@ -487,16 +487,26 @@ int PrintPreviewCreator_PDF::renderPreviewSep(int pageIndex, int res)
 	m_doc->getUsedColors(usedSpots, true);
 	QStringList spots = usedSpots.keys();
 	args3.append( "-sDEVICE=tiffsep" );
+	if (m_gsVersion >= 954)
+		args3.append( "-dPrintSpotCMYK=true" );
 
-//	args3.append( "-c" );
-	cmd = "<< /SeparationColorNames ";
 	QString allSeps ="[ /Cyan /Magenta /Yellow /Black ";
 	for (int sp = 0; sp < spots.count(); ++sp)
 	{
 		allSeps += "(" + spots[sp] + ") ";
 	}
 	allSeps += "]";
-	cmd += allSeps + " /SeparationOrder [ /Cyan /Magenta /Yellow /Black] >> setpagedevice";
+
+	// Workaround for https://bugs.ghostscript.com/show_bug.cgi?id=707365
+	// This issue causes separations rendered individually to be garbled,
+	// so render files with a reasonable number of spot colors in one go
+	constexpr int maxSpotColors = 4;
+	cmd = "<< /SeparationColorNames ";
+	if (spots.count() <= maxSpotColors)
+		cmd += allSeps + " /SeparationOrder " + allSeps + " >> setpagedevice";
+	else
+		cmd += allSeps + " /SeparationOrder [ /Cyan /Magenta /Yellow /Black] >> setpagedevice";
+
 	QFile fx(QDir::toNativeSeparators(ScPaths::tempFileDir() + "/" +  m_tempBaseName + ".sep.ps"));
 	if (fx.open(QIODevice::WriteOnly))
 	{
@@ -512,13 +522,31 @@ int PrintPreviewCreator_PDF::renderPreviewSep(int pageIndex, int res)
 	m_sepsToFileNum.clear();
 	if (sepInfo.open(QIODevice::ReadOnly))
 	{
-		QString Sname;
+		QString sepLine;
 		QTextStream tsC(&sepInfo);
 		int counter = 0;
 		while (!tsC.atEnd())
 		{
-			Sname = tsC.readLine();
-			QString tt = Sname.remove("%%SeparationName:").trimmed();
+			sepLine = tsC.readLine();
+			if (sepLine.startsWith("Warning"))
+				continue;
+			QString tt;
+			if (sepLine.contains("%%SeparationColor:"))
+			{
+				int firstQuote = sepLine.indexOf('\"');
+				int lastQuote = sepLine.lastIndexOf('\"');
+				if (firstQuote >= 0 && lastQuote >= 0 && firstQuote < lastQuote)
+					tt = sepLine.mid(firstQuote + 1, lastQuote - firstQuote - 1);
+			}
+			else
+			{
+				tt = sepLine.remove("%%SeparationName:").trimmed();
+				int cmykVals = tt.lastIndexOf("CMYK =");
+				if (cmykVals >= 0)
+					tt = tt.left(cmykVals).trimmed();
+			}
+			if (tt == "Cyan" || tt == "Magenta" || tt == "Yellow" || tt == "Black")
+				tt.clear();
 			if (!tt.isEmpty())
 			{
 				m_sepsToFileNum.insert(tt, counter);
@@ -527,13 +555,14 @@ int PrintPreviewCreator_PDF::renderPreviewSep(int pageIndex, int res)
 		}
 	}
 	sepInfo.close();
-	QString currSeps = "";
+
+	QString currSeps;
 	uint spc = 0;
-	for (int sp = 0; sp < spots.count(); ++sp)
+	for (int sp = maxSpotColors; sp < spots.count(); ++sp)
 	{
 		currSeps += "(" + spots[sp] + ") ";
 		spc++;
-		if (sp > 6)
+		if (spc > 6 || sp == spots.count() - 1)
 		{
 			args3.clear();
 			args3.append("-sDEVICE=tiffsep");
@@ -547,25 +576,10 @@ int PrintPreviewCreator_PDF::renderPreviewSep(int pageIndex, int res)
 			args3.append("-f");
 			args3.append(QDir::toNativeSeparators(ScPaths::tempFileDir() + "/" +  m_tempBaseName + ".sep.ps"));
 			ret = System(gsExe, args1 + args3 + args2);
-			currSeps = "";
+			currSeps.clear();
 			spc = 0;
 		}
 	}
-	if (spc != 0)
-	{
-		args3.clear();
-		args3.append("-sDEVICE=tiffsep");
-		QFile fx(QDir::toNativeSeparators(ScPaths::tempFileDir() + "/" +  m_tempBaseName + ".sep.ps"));
-		if (fx.open(QIODevice::WriteOnly))
-		{
-			QTextStream tsx(&fx);
-			tsx << QString("<< /SeparationColorNames " + allSeps+" /SeparationOrder [ " + currSeps + " ] >> setpagedevice");
-			fx.close();
-		}
-		args3.append("-f");
-		args3.append(QDir::toNativeSeparators(ScPaths::tempFileDir() + "/" +  m_tempBaseName + ".sep.ps"));
-		ret = System(gsExe, args1 + args3 + args2);
-	}
 	return ret;
 }
 
