@@ -551,7 +551,7 @@ public:
 	bool isDefaultStyle( const CharStyle& c ) const { return m_docCharStyles.isDefault(c); }
 // 	bool isDefaultStyle( LineStyle& l ) const { return docLineStyles......; }
 
-	const QHash<QString, multiLine>& lineStyles() const { return docLineStyles; }
+	const QHash<QString, MultiLine>& lineStyles() const { return docLineStyles; }
 
 	/**
 	 * Returns the table style named @a name.
@@ -648,7 +648,7 @@ public:
 	 */
 	void loadStylesFromFile(const QString& fileName, StyleSet<ParagraphStyle> *tempStyles,
 	                                          StyleSet<CharStyle> *tempCharStyles,
-											  QHash<QString, multiLine> *tempLineStyles);
+											  QHash<QString, MultiLine> *tempLineStyles);
 
 	const CharStyle& charStyle(const QString& name) const { return m_docCharStyles.get(name); }
 	const StyleSet<CharStyle>& charStyles() const { return m_docCharStyles; }
@@ -1446,7 +1446,7 @@ public:
 	bool isConverted {false};
 	QTimer * const autoSaveTimer;
 	QList<QString> autoSaveFiles;
-	QHash<QString, multiLine> docLineStyles;
+	QHash<QString, MultiLine> docLineStyles;
 	QHash<QString, ScPattern> docPatterns;
 	QHash<QString, VGradient> docGradients;
 	QWidget* WinHan {nullptr};
@@ -1534,8 +1534,13 @@ public slots:
 	void itemSelection_SetItemFillBlend(int t);
 	void itemSelection_SetItemLineBlend(int t);
 	void itemSelection_SetLineGradient(const VGradient& newGradient, Selection* customSelection = nullptr);
+	void itemSelection_SetLineGradientExtend(VGradient::VGradientRepeatMethod repeatMethod, Selection* customSelection = nullptr);
+	void itemSelection_SetLineGradientName(const QString& gradientName, Selection* customSelection = nullptr);
 	void itemSelection_SetFillGradient(const VGradient& newGradient, Selection* customSelection = nullptr);
+	void itemSelection_SetFillGradientExtend(VGradient::VGradientRepeatMethod repeatMethod, Selection* customSelection = nullptr);
+	void itemSelection_SetFillGradientName(const QString& gradientName, Selection* customSelection = nullptr);
 	void itemSelection_SetMaskGradient(const VGradient& newGradient, Selection* customSelection = nullptr);
+	void itemSelection_SetMaskGradientName(const QString& gradientName, Selection* customSelection = nullptr);
 	void itemSelection_SetOverprint(bool overprint, Selection* customSelection = nullptr);
 	void itemSelection_ApplyImageEffects(ScImageEffectList& newEffectList, Selection* customSelection = nullptr);
 	void itemSelection_FlipH(Selection* customSelection = nullptr);
