@@ -19,7 +19,7 @@ public:
 	FileDialogEventCatcher(QObject* parent);
 
 protected:
-	virtual bool eventFilter(QObject *o, QEvent *e);
+	bool eventFilter(QObject *o, QEvent *e) override;
 	
 signals:
 	void escapePressed();
